@@ -1881,7 +1881,7 @@ def find_shortest_path(source_node=None, connected_pairs=None, num_nodes=None, t
     graph = pairs_to_graph(connected_pairs, num_nodes) # return sparse matrix
     dist_info = np.empty((num_nodes, 3), dtype=int) # node, dist, last node
     dist_info[:,0] = np.arange(num_nodes)
-    dist_info[:,1] = np.iinfo(np.int64).max
+    dist_info[:,1] = num_nodes # np.iinfo(np.int64).max
     dist_info[:,2] = -1
     source_node = int(source_node)
     queque.append(source_node+1)
@@ -1953,10 +1953,14 @@ def return_csr_matrix_indices(csr_matrix):
 
 
 
-
-
-
-
+def load_data(name='vdu_signals'):
+    this_dir, this_filename = os.path.split(__file__)
+    
+    if name == 'vdu_signals':
+        DATA_PATH = os.path.join(this_dir, 'data/vdu_signals.npy')
+        return np.load(DATA_PATH)
+    else:
+        warnings.warn("Currently not support this data.")
 
 
 
